@@ -96,6 +96,18 @@ class ExtTreeView(gtk.TreeView):
         else:            return self.store.get_iter(path)
 
 
+    def scroll(self, path):
+        """ Ensure that path is visible """
+        self.scroll_to_cell(path)
+
+
+    def selectPaths(self, paths):
+        """ Select all the given paths """
+        self.selection.unselect_all()
+        for path in paths:
+            self.selection.select_path(path)
+
+
     # --== Retrieving content ==--
 
 
@@ -202,7 +214,7 @@ class ExtTreeView(gtk.TreeView):
 
     def appendRow(self, row, parentPath=None):
         """ Append a row to the tree """
-        self.store.append(self.__getSafeIter(parentPath), row)
+        return self.store.get_path(self.store.append(self.__getSafeIter(parentPath), row))
 
 
     def appendRows(self, rows, parentPath=None):
@@ -245,6 +257,11 @@ class ExtTreeView(gtk.TreeView):
     # --== Changing the state of nodes ==--
 
 
+    def expandRow(self, path):
+        """ Expand the given row """
+        self.expand_row(path, False)
+
+
     def expandRows(self, paths=None):
         """ Expand the given rows, or the selected rows if paths is None """
         if paths is None:
@@ -311,11 +328,11 @@ class ExtTreeView(gtk.TreeView):
         (visibleRange, selectedRows, expandedNodes) = state
 
         for (row, name) in expandedNodes:
-            if self.isValidPath(row) and self.getRow(row)[nameIndex] == name:
+            if self.isValidPath(row) and self.getRow(row)[nameIndex] == name and not self.row_expanded(row):
                 self.expand_row(row, False)
 
         if visibleRange is not None:
-            self.scroll_to_cell(visibleRange[0])
+            self.scroll(visibleRange[0])
 
         for path in selectedRows:
             self.selection.select_path(path)
