@@ -35,9 +35,10 @@ PREFS_DFT_USE_CACHE = True
 # Format of a row in the treeview
 (
     ROW_PIXBUF,
+    ROW_LENGTH,
     ROW_NAME,
     ROW_TRACK
-) = range(3)
+) = range(4)
 
 
 # Information returned by disc_id()
@@ -58,8 +59,14 @@ class AudioCD(modules.ThreadedModule):
 
     def onModLoaded(self):
         """ The module has been loaded """
-        columns = (('',   [(gtk.CellRendererPixbuf(), gtk.gdk.Pixbuf), (gtk.CellRendererText(), gobject.TYPE_STRING)], True),
-                   (None, [(None, gobject.TYPE_PYOBJECT)],                                                             False))
+        txtRdrLen = gtk.CellRendererText()
+
+        columns = (('',   [(gtk.CellRendererPixbuf(), gtk.gdk.Pixbuf), (txtRdrLen, gobject.TYPE_STRING), (gtk.CellRendererText(), gobject.TYPE_STRING)], True),
+                   (None, [(None, gobject.TYPE_PYOBJECT)],                                                                                               False))
+
+        # The album length is written in a smaller font, with a lighter color
+        txtRdrLen.set_property('scale', 0.85)
+        txtRdrLen.set_property('foreground', '#909090')
 
         self.tree     = extTreeview.ExtTreeView(columns, True)
         self.popup    = None
@@ -79,6 +86,15 @@ class AudioCD(modules.ThreadedModule):
         self.tree.connect('exttreeview-button-pressed', self.onButtonPressed)
         modules.postMsg(consts.MSG_CMD_EXPLORER_ADD, {'modName': MOD_L10N, 'expName': self.expName, 'icon': consts.icoCdrom, 'widget': self.scrolled})
 
+        # Hide the album length when not drawing the root node
+        self.tree.get_column(0).set_cell_data_func(txtRdrLen, self.__drawAlbumLenCell)
+
+
+    def __drawAlbumLenCell(self, column, cell, model, iter):
+        """ Use a different background color for alphabetical headers """
+        if model.get_value(iter, ROW_LENGTH) is None: cell.set_property('visible', False)
+        else:                                         cell.set_property('visible', True)
+
 
     def onModUnloaded(self):
         """ The module is going to be unloaded """
@@ -147,10 +163,10 @@ class AudioCD(modules.ThreadedModule):
     def createTree(self, nbTracks):
         """ Create a temporary explorer tree without disc information """
         name = '%s  <span size="smaller" foreground="#909090">%s</span>' % (MOD_L10N, _('downloading data...'))
-        self.tree.replaceContent(((consts.icoCdrom, name, None),))
+        self.tree.replaceContent(((consts.icoCdrom, None, name, None),))
 
         # Append a child for each track
-        self.tree.appendRows([(consts.icoMediaFile, _('Track %02u') % (i+1), None) for i in xrange(nbTracks)], (0,))
+        self.tree.appendRows([(consts.icoMediaFile, None, _('Track %02u') % (i+1), None) for i in xrange(nbTracks)], (0,))
         self.tree.expand_all()
 
 
@@ -170,9 +186,10 @@ class AudioCD(modules.ThreadedModule):
 
         # Update the root of the tree
         disc          = cddb['DTITLE'].strip().decode('iso-8859-15', 'replace')
-        rowName       = '<span size="smaller" foreground="#909090">[%s]</span>  %s' % (sec2str(sum(trackLen)), cgi.escape(disc))
         artist, album = disc.split(' / ')
-        self.tree.setItem((0,), ROW_NAME, rowName)
+
+        self.tree.setItem((0,), ROW_NAME, '%s' % cgi.escape(disc))
+        self.tree.setItem((0,), ROW_LENGTH, '[%s]' % sec2str(sum(trackLen)))
 
         # Update the explorer name
         modules.postMsg(consts.MSG_CMD_EXPLORER_RENAME, {'modName': MOD_L10N, 'expName': self.expName, 'newExpName': disc})
