@@ -16,7 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 
-import dbus, dbus.service, gobject, modules, traceback
+import dbus, dbus.service, gobject, media, modules, traceback
 
 from tools import consts, log
 
@@ -56,13 +56,13 @@ class DBusInterface(dbus.service.Object):
     @dbus.service.method(consts.dbusInterface, in_signature='uas', out_signature='b')
     def sendMsg(self, msg, params):
         """ Send the given message and its parameters to the core """
-        if msg in [consts.MSG_CMD_TOGGLE_PAUSE,  consts.MSG_CMD_NEXT, consts.MSG_CMD_PREVIOUS, consts.MSG_CMD_STOP,
-                   consts.MSG_CMD_TRACKLIST_CLR, consts.MSG_CMD_TRACKLIST_SHUFFLE]:
+        if msg in (consts.MSG_CMD_TOGGLE_PAUSE,  consts.MSG_CMD_NEXT, consts.MSG_CMD_PREVIOUS, consts.MSG_CMD_STOP,
+                   consts.MSG_CMD_TRACKLIST_CLR, consts.MSG_CMD_TRACKLIST_SHUFFLE):
             gobject.idle_add(modules.postMsg, msg)
         elif msg == consts.MSG_CMD_TRACKLIST_ADD:
-            gobject.idle_add(modules.postMsg, msg, {'files': [file for file in params]})
+            gobject.idle_add(modules.postMsg, msg, {'tracks': media.getTracks([file for file in params])})
         elif msg == consts.MSG_CMD_TRACKLIST_SET:
-            gobject.idle_add(modules.postMsg, msg, {'files': [file for file in params], 'playNow': True})
+            gobject.idle_add(modules.postMsg, msg, {'tracks': media.getTracks([file for file in params]), 'playNow': True})
         elif msg == consts.MSG_CMD_SET_VOLUME:
             gobject.idle_add(modules.postMsg, msg, {'value': float(params[0]) / 100.0})
         else:
