@@ -30,7 +30,7 @@ MOD_L10N = MOD_INFO[modules.MODINFO_L10N]
 PREFS_DEFAULT_BODY       = 'by {artist}\nfrom {album}\n\nTrack {playlist_pos} out of {playlist_len}'
 PREFS_DEFAULT_TITLE      = '{title}  [{duration_str}]'
 PREFS_DEFAULT_TIMEOUT    = 10
-PREFS_DEFAULT_SKIP_TRACK = True
+PREFS_DEFAULT_SKIP_TRACK = False
 
 
 class DesktopNotification(modules.ThreadedModule):
@@ -112,11 +112,16 @@ class DesktopNotification(modules.ThreadedModule):
     def configure(self, parent):
         """ Show the configuration window """
         if self.cfgWin is None:
+            import pynotify
+
             self.cfgWin = gui.window.Window('DesktopNotification.glade', 'vbox1', __name__, MOD_L10N, 355, 345)
             self.cfgWin.getWidget('btn-ok').connect('clicked', self.onBtnOk)
             self.cfgWin.getWidget('btn-help').connect('clicked', self.onBtnHelp)
             self.cfgWin.getWidget('btn-cancel').connect('clicked', lambda btn: self.cfgWin.hide())
 
+            if 'actions' not in pynotify.get_server_caps():
+                self.cfgWin.getWidget('chk-skipTrack').set_sensitive(False)
+
         if not self.cfgWin.isVisible():
             self.cfgWin.getWidget('txt-title').set_text(prefs.get(__name__, 'title', PREFS_DEFAULT_TITLE))
             self.cfgWin.getWidget('spn-duration').set_value(prefs.get(__name__, 'timeout', PREFS_DEFAULT_TIMEOUT))
